@@ -5,21 +5,15 @@
 #include <stdint.h>
 #include <stdbool.h>
 
-#ifdef FF_USE_SYSTEM_YYJSON
-    #include <yyjson.h>
-#else
-    #include "3rdparty/yyjson/yyjson.h"
-#endif
-
 #ifdef _MSC_VER
     #define __attribute__(x)
 #endif
 
-#include "util/arrayUtils.h"
-#include "util/FFstrbuf.h"
-#include "util/FFlist.h"
-#include "util/platform/FFPlatform.h"
-#include "util/unused.h"
+#include "common/arrayUtils.h"
+#include "common/FFstrbuf.h"
+#include "common/FFlist.h"
+#include "common/FFPlatform.h"
+#include "common/unused.h"
 
 #include "options/logo.h"
 #include "options/display.h"
@@ -40,13 +34,8 @@ typedef struct FFstate
     uint32_t keysHeight;
     bool terminalLightTheme;
     bool titleFqdn;
-
-    FFPlatform platform;
-    yyjson_doc* configDoc;
-    yyjson_mut_doc* resultDoc;
-    FFstrbuf genConfigPath;
-    bool fullConfig;
     uint32_t dynamicInterval;
+    FFPlatform platform;
 } FFstate;
 
 typedef struct FFinstance
